# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import enum

import winrt.system
from winrt import _winrt_windows_devices_portable

__all__ = [
    "ServiceDeviceType",
    "ServiceDevice",
    "StorageDevice",
]

class ServiceDeviceType(enum.IntEnum):
    CALENDAR_SERVICE = 0
    CONTACTS_SERVICE = 1
    DEVICE_STATUS_SERVICE = 2
    NOTES_SERVICE = 3
    RINGTONES_SERVICE = 4
    SMS_SERVICE = 5
    TASKS_SERVICE = 6

ServiceDevice = _winrt_windows_devices_portable.ServiceDevice
StorageDevice = _winrt_windows_devices_portable.StorageDevice
